@@ -24,7 +24,6 @@ description	:
 #include <qpopupmenu.h>
 #include <qregexp.h>
 #include <qstring.h>
-#include <qtabwidget.h>
 #include <qtooltip.h>
 
 #include <kconfig.h>
@@ -33,6 +32,7 @@ description	:
 #include <kglobal.h>
 #include <klocale.h>
 #include <kmimetype.h>
+#include <ktabwidget.h>
 
 #include "apollonqueryview.h"
 #include "apollonsearchviewitem.h"
@@ -55,6 +55,13 @@ ApollonQueryView::ApollonQueryView(KTabWidget *parent, int ID, int index, const
 	m_loader = KGlobal::iconLoader();
 
 	QHBox *box = new QHBox(this);
+
+	// initialize the results listview
+	m_searchResults = new ApollonSearchListView(this);
+
+	connect(m_searchResults, SIGNAL(doubleClicked(QListViewItem *)), this, SLOT(itemDoubleClicked(QListViewItem *)));
+	connect(m_searchResults, SIGNAL(rightButtonPressed(QListViewItem*, const QPoint&, int)), this, SLOT(queryPopup(QListViewItem*, const QPoint&, int)));
+
 	QHBox *box2 = new QHBox(this);
 
 	m_iconLabel = new QLabel(box);
@@ -66,49 +73,52 @@ ApollonQueryView::ApollonQueryView(KTabWidget *parent, int ID, int index, const
 	{
 		case 0:
 			realm = i18n("Everything");
-			m_iconLabel->setPixmap(m_loader->loadIcon("find", KIcon::Small));
+			m_iconLabel->setPixmap(m_loader->loadIcon("find", KIcon::Toolbar));
 			break;
 		case 1:
 			realm = i18n("Audio");
-			m_iconLabel->setPixmap(m_loader->loadIcon("sound", KIcon::Small));
+			m_iconLabel->setPixmap(m_loader->loadIcon("sound", KIcon::Toolbar));
 			break;
 		case 2:
 			realm = i18n("Video");
-			m_iconLabel->setPixmap(m_loader->loadIcon("video", KIcon::Small));
+			m_iconLabel->setPixmap(m_loader->loadIcon("video", KIcon::Toolbar));
 			break;
 		case 3:
 			realm = i18n("Images");
-			m_iconLabel->setPixmap(m_loader->loadIcon("image", KIcon::Small));
+			m_iconLabel->setPixmap(m_loader->loadIcon("image", KIcon::Toolbar));
 			break;
 		case 4:
 			realm = i18n("Text documents");
-			m_iconLabel->setPixmap(m_loader->loadIcon("txt", KIcon::Small));
+			m_iconLabel->setPixmap(m_loader->loadIcon("txt", KIcon::Toolbar));
 			break;
 		case 5:
 			realm = i18n("Software");
-			m_iconLabel->setPixmap(m_loader->loadIcon("binary", KIcon::Small));
+			m_iconLabel->setPixmap(m_loader->loadIcon("binary", KIcon::Toolbar));
 			break;
 
 		case 6:
 			// These are not allowed as realm
 			//realm = i18n("User");
-			m_iconLabel->setPixmap(m_loader->loadIcon("connect_established", KIcon::Small));
+			//m_iconLabel->setPixmap(m_loader->loadIcon("connect_established", KIcon::Small));
 			break;
 		case 7:
 			// These are not allowed as realm
 			//realm = "hash";
-			m_iconLabel->setPixmap(m_loader->loadIcon("help_index", KIcon::Small));
+			//m_iconLabel->setPixmap(m_loader->loadIcon("help_index", KIcon::Small));
 			break;
 	}
 
-	m_textSearchString = i18n("Results for <i>%1</i> with keywords <i>%2</i> - Searching...").arg(realm).arg(text);
-	m_textCompleteString = i18n("Results for <i>%1</i> with keywords <i>%2</i> - Search completed!").arg(realm).arg(text);
+
+	//box->addWidget(m_iconLabel);
+	m_textSearchString = i18n("Searching for <i>%1</i>... ").arg(text);
+	m_textCompleteString = i18n("Search <b>completed</b> for <i>%1</i>... ").arg(text);
 
 	m_summaryLabel->setText(m_textSearchString);
 
 	// initialize Search More button
 	m_moreButton = new QPushButton(box);
 	m_moreButton->setText(i18n("Search More"));
+	m_moreButton->setIconSet(m_loader->loadIcon("edit_add", KIcon::Small));
 	m_moreButton->setFixedHeight(m_moreButton->sizeHint().height());
 	m_moreButton->setFixedWidth(m_moreButton->sizeHint().width());
 	connect(m_moreButton, SIGNAL(clicked()), this, SLOT(moreSearch()));
@@ -124,16 +134,20 @@ ApollonQueryView::ApollonQueryView(KTabWidget *parent, int ID, int index, const
 	QToolTip::add(m_stopButton, i18n("Stop search (esc)"));
 
 	// initialize Close button
-	QPushButton *closeButton = new QPushButton(box);
-	closeButton->setPixmap(m_loader->loadIcon("fileclose", KIcon::Small));
-	closeButton->setFixedHeight(closeButton->sizeHint().height());
-	closeButton->setFixedWidth(closeButton->sizeHint().width());
-	connect(closeButton, SIGNAL(clicked()), this, SLOT(deleteThis()));
-	QToolTip::add(closeButton, i18n("Close tab (Ctrl-w)"));
+// 	QPushButton *closeButton = new QPushButton(box);
+// 	closeButton->setPixmap(m_loader->loadIcon("tab_remove", KIcon::Small));
+// 	closeButton->setFixedHeight(closeButton->sizeHint().height());
+// 	closeButton->setFixedWidth(closeButton->sizeHint().width());
+// 	connect(closeButton, SIGNAL(clicked()), this, SLOT(deleteThis()));
+// 	QToolTip::add(closeButton, i18n("Close tab (Ctrl-w)"));
 
 	box->setStretchFactor(m_summaryLabel, 4);
-	box->setStretchFactor(closeButton, 0);
+	//box->setStretchFactor(closeButton, 0);
+	box->setSpacing(7);
+	box->setMargin(7);
 
+	m_filterLabel = new QLabel(box2);
+	m_filterLabel->setText( i18n("Filter results : ") );
 	QComboBox *filterColumnCombo = new QComboBox(box2);
 	filterColumnCombo->insertItem(i18n("File Name"), 0);
 	filterColumnCombo->insertItem(i18n("User"), 1);
@@ -145,6 +159,10 @@ ApollonQueryView::ApollonQueryView(KTabWidget *parent, int ID, int index, const
 	filterColumnCombo->insertItem(i18n("Bitrate"), 7);
 	filterColumnCombo->insertItem(i18n("Category"), 8);
 	filterColumnCombo->insertItem(i18n("Directory"), 9);
+
+	box2->setSpacing(7);
+	box2->setMargin(7);
+
 	connect(filterColumnCombo, SIGNAL(activated(int)), this, SLOT(updateFilterColumn(int)));
 
 	QComboBox *filterModeCombo = new QComboBox(box2);
@@ -153,21 +171,16 @@ ApollonQueryView::ApollonQueryView(KTabWidget *parent, int ID, int index, const
 	filterModeCombo->insertItem(i18n("doesn't contain"), 2);
 	connect(filterModeCombo, SIGNAL(activated(int)), this, SLOT(updateFilterMode(int)));
 
-	m_findBox = new QLineEdit(box2);
-
 	m_clearButton = new QPushButton(box2);
-	m_clearButton->setText(i18n("Clear"));
+	m_clearButton->setPixmap(m_loader->loadIcon("locationbar_erase", KIcon::Small));
 	m_clearButton->setEnabled(false);
+	QToolTip::add(m_clearButton, i18n("Clear the filter"));
+
+	m_findBox = new QLineEdit(box2);
 
 	connect(m_findBox,     SIGNAL(textChanged(const QString &)), this, SLOT(findItems(const QString &)));
 	connect(m_clearButton, SIGNAL(clicked()),                    this, SLOT(clearFindbox()));
 
-	// initialize the results listview
-	m_searchResults = new ApollonSearchListView(this);
-
-	connect(m_searchResults, SIGNAL(doubleClicked(QListViewItem *)), this, SLOT(itemDoubleClicked(QListViewItem *)));
-	connect(m_searchResults, SIGNAL(rightButtonPressed(QListViewItem*, const QPoint&, int)), this, SLOT(queryPopup(QListViewItem*, const QPoint&, int)));
-
 	// right-mouse-button menu for parent items
 	m_itemMenu = new QPopupMenu(m_searchResults);
 
@@ -373,8 +386,8 @@ void ApollonQueryView::addItem(QString searchReply)
 
 				p->setVisible(itemVisible(p));
 
-				m_summaryLabel->setText(m_textSearchString + i18n(" (1 result)",
-				                                                  " (%n results)", m_searchResults->childCount()));
+				m_summaryLabel->setText(m_textSearchString + i18n("  <b>1</b> result",
+				                                                  "  <b>%n</b> results", m_searchResults->childCount()));
 			}
 			else
 			{
@@ -400,9 +413,9 @@ void ApollonQueryView::addItem(QString searchReply)
 
 			if(QString::compare(endSearch, searchReply) == 0)
 			{
-				m_summaryLabel->setText(m_textCompleteString + i18n(" (1 result)",
-				                                                    " (%n results)", m_searchResults->childCount()));
-				m_parent->changeTab(this, m_query + i18n(" (finished)"));
+				m_summaryLabel->setText(m_textCompleteString + i18n("  <b>1</b> result",
+				                                                    "  <b>%n</b> results", m_searchResults->childCount()));
+				m_parent->changeTab(this, m_query + i18n(" (complete)"));
 				m_moreButton->setEnabled(true);
 				m_stopButton->setEnabled(false);
 			}
@@ -566,3 +579,5 @@ void ApollonQueryView::slotDeleteHash(QString hash)
 	}
 }
 
+#include "apollonqueryview.moc"
+
