@@ -29,7 +29,7 @@ description	:
 #include <kiconloader.h>
 
 #include "giftconnection.h"
-#include "ktabwidget.h"
+
 #include "apollonlistview.h"
 #include "apollonsearchlistview.h"
 
@@ -40,8 +40,7 @@ class QListViewItem;
 class QPopupMenu;
 class QString;
 class QStringList;
-class QTabWidget;
-
+class KTabWidget;
 class ApollonViewTab;
 class ApollonSearchViewItem;
 
@@ -91,6 +90,7 @@ class ApollonQueryView : public QVBox
 		KTabWidget      *m_parent;
 		int              m_id;
 		int              m_index;
+		QLabel          *m_filterLabel;
 		QLabel          *m_iconLabel;
 		QLabel          *m_summaryLabel;
 		QLineEdit       *m_findBox;
