@@ -2,8 +2,8 @@
                           apollonsearchtab.cpp  -  description
                              -------------------
 begin		: Dec 05 2003
-copyright	: (C) 2002 by Bastiaan Naber, (C) 2002 by Robert Wittams
-email		: bastiaan@ricardis.tudelft.nl
+copyright	: (C) 2005 by Martin Koebele, (C) 2002 by Bastiaan Naber, (C) 2002 by Robert Wittams
+email		: martin@mkoebele.de
 description	:
 
  ***************************************************************************/
@@ -20,21 +20,25 @@ description	:
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <klocale.h>
+#include <ktabwidget.h>
+#include <kcompletion.h>
+#include <klineedit.h>
+#include <kcombobox.h>
+#include <kdeversion.h>
 
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
 #include <qpushbutton.h>
-#include <qtabwidget.h>
 #include <qpixmap.h>
 #include <qvbox.h>
 #include <qsizepolicy.h>
+ 
+#include <qtabbar.h>
 
 #include "apollonsearchtab.h"
 #include "giftconnection.h"
 
-#define MAX_TABTEXT_CHARS 20
+#define MAX_TABTEXT_CHARS 25
 
 ApollonSearchTab::ApollonSearchTab(QWidget* parent, const char *name, giFTConnection* gcn): ApollonTab(parent, name, gcn)
 {
@@ -48,7 +52,7 @@ ApollonSearchTab::ApollonSearchTab(QWidget* parent, const char *name, giFTConnec
 	splitter = new QVBox(this);
 
 	QWidget* searchpanel = new QWidget(splitter);
-	QGridLayout *grid = new QGridLayout(searchpanel, 2, 3);
+	QGridLayout *grid = new QGridLayout(searchpanel, 2, 4, 6);
 
 	QLabel* querylabel = new QLabel(searchpanel);
 	querylabel->setText(i18n("Search for "));
@@ -58,12 +62,16 @@ ApollonSearchTab::ApollonSearchTab(QWidget* parent, const char *name, giFTConnec
 	keylabel->setText(i18n("with keywords: "));
 	keylabel->setFixedHeight( 20 );
 
-	querybox = new QLineEdit(searchpanel);
+	querybox = new KLineEdit(searchpanel);
+
+	KCompletion *comp = querybox->completionObject();
+	// Connect to the return pressed signal - optional
+ 	connect(querybox,SIGNAL(returnPressed(const QString&)),comp,SLOT(addItem(const QString&)));
 
 	// This is a default text to make hacking easier
 	//querybox->setText("MTV britney");
 
-	querycombo = new QComboBox(searchpanel);
+	querycombo = new KComboBox(searchpanel);
 
 	querycombo->insertItem(loader->loadIcon("find",KIcon::Small) , i18n("Everything"), 0 );
 	querycombo->insertItem(loader->loadIcon("sound",KIcon::Small), i18n("Audio"), 1 );
@@ -75,33 +83,52 @@ ApollonSearchTab::ApollonSearchTab(QWidget* parent, const char *name, giFTConnec
 	/*
 	querycombo->insertItem(loader->loadIcon("help_index",KIcon::Small), "hash", 7 );
 	*/
-	QPushButton* go = new QPushButton(searchpanel);
-	go->setPixmap( loader->loadIcon("down", KIcon::Toolbar));
+	QPushButton* goButton = new QPushButton(searchpanel);
+	goButton->setPixmap( loader->loadIcon("ok", KIcon::Toolbar));
+
+	QPushButton* clearButton = new QPushButton(searchpanel);
+	clearButton->setPixmap( loader->loadIcon("locationbar_erase", KIcon::Toolbar));
 
 	grid->addWidget(querylabel, 0, 0);
 	grid->addWidget(querycombo, 0, 1);
-	grid->addWidget(keylabel, 1, 0);
-	grid->addWidget(querybox, 1, 1);
-	grid->addWidget(go, 1, 2);
-
-	grid->setRowStretch(0, 0);
-	grid->setRowStretch(1, 0);
-	grid->setColStretch(0, 0);
-	grid->setColStretch(1, 1);
-	grid->setColStretch(2, 0);
+	grid->addWidget(keylabel, 0, 2);
+	grid->addWidget(clearButton, 0, 3);	
+	grid->addWidget(querybox, 0, 4);
+	grid->addWidget(goButton, 0, 5);	
+	
 
 	viewtab = new KTabWidget(splitter);
+
 	makePopup();
 	clickedTab = NULL;
 
-
 	connect(viewtab, SIGNAL(currentChanged(QWidget*)), this, SLOT(sltChangeTab(QWidget*)));
 	connect(viewtab, SIGNAL(contextMenu(QWidget*,const QPoint&)), this, SLOT(tabContextMenu(QWidget*,const QPoint&)));
-	connect( go, SIGNAL(clicked()),			this, SLOT(startSearch()) );
+	connect( goButton, SIGNAL(clicked()),			this, SLOT(startSearch()) );
 	connect( querybox, SIGNAL(returnPressed()), 	this, SLOT(startSearch()) );
 	connect(m_gcn, SIGNAL(giftItemReply(QString)), this,SIGNAL(giftItemReply(QString)));
+	connect(clearButton, SIGNAL(clicked()), querybox, SLOT(clear()));
 
-	viewtab->setTabPosition(QTabWidget::Bottom);
+	viewtab->setTabPosition(QTabWidget::Top);
+	viewtab->setHoverCloseButton( true );
+	
+	
+	closeButton = new QPushButton(viewtab);
+	closeButton->setPixmap(loader->loadIcon("tab_remove", KIcon::Small));
+	closeButton->setFixedHeight(closeButton->sizeHint().height());
+	closeButton->setFixedWidth(closeButton->sizeHint().width());
+	connect(closeButton, SIGNAL(clicked()), this, SLOT(closeCurrentTab()));
+	QToolTip::add(closeButton, i18n("Close tab (Ctrl-w)"));
+	
+	viewtab->setCornerWidget(closeButton);
+	viewtab->setHidden(true);
+
+#if KDE_IS_VERSION (3,4,0)	
+	viewtab->setTabBarHidden(true);
+	viewtab->setAutomaticResizeTabs(true);
+#else	
+	closeButton->setHidden(true);
+#endif
 }
 
 
@@ -113,7 +140,7 @@ ApollonSearchTab::~ApollonSearchTab()
 void ApollonSearchTab::startQuery(const int &index, const QString &text)
 {
 	KIconLoader *loader = KGlobal::iconLoader();
-
+	
 	int ID = m_gcn->getNewID();
 
 	m_gcn->makeSearchRequest(ID, index, text);
@@ -166,12 +193,14 @@ void ApollonSearchTab::startQuery(const int &index, const QString &text)
 
 	}
 
-	//viewtab->addTab(kqv, icon, tabtext + i18n(" (%1 results)").arg(0));
 	viewtab->addTab(kqv, icon, tabtext + i18n(" (searching...)"));
-
-	//tabbar->addTab(new QTab(icon, tabtext + i18n(" (searching...)")));
-
 	viewtab->showPage(kqv);
+	viewtab->setHidden(false);
+#if KDE_IS_VERSION (3,4,0)
+	viewtab->setTabBarHidden(false);
+#else
+        closeButton->setHidden(false);
+#endif
 
 	connect(this, SIGNAL(giftItemReply(QString)),                                      kqv,   SLOT(addItem(QString)));
 	connect(kqv,  SIGNAL(giftAddRequest(QString, QString, QString, QString, QString)), m_gcn, SLOT(makeAddRequest(QString, QString, QString, QString, QString)));
@@ -238,12 +267,43 @@ void ApollonSearchTab::closealltabs()
 	{
 		kqv->deleteThis();
 	}
+#if KDE_IS_VERSION (3,4,0)
+	viewtab->setTabBarHidden(true);
+#else
+        closeButton->setHidden(true);
+#endif
+
 }
 
 void ApollonSearchTab::closeThisTab()
 {
 	if (clickedTab)
 		((ApollonQueryView*)clickedTab)->deleteThis();
+	
+	if (viewtab->currentPage() == 0) {
+#if KDE_IS_VERSION (3,4,0)
+	        viewtab->setTabBarHidden(true);
+#else
+        	closeButton->setHidden(true);
+#endif
+
+	}
+}
+
+void ApollonSearchTab::closeCurrentTab()
+{
+	ApollonQueryView* tab = dynamic_cast<ApollonQueryView*>(viewtab->currentPage());
+	if (tab) {
+		tab->deleteThis();
+	}
+	if (viewtab->currentPage() == 0) {
+#if KDE_IS_VERSION (3,4,0)
+	        viewtab->setTabBarHidden(true);
+#else
+        	closeButton->setHidden(true);
+#endif
+
+	}
 }
 
 void ApollonSearchTab::tabContextMenu( QWidget *target, const QPoint &pos )
@@ -295,3 +355,6 @@ void ApollonSearchTab::slotDeleteHash(QString hash)
 	if( m_hashList->remove(hash) )
 		emit sigDeleteHash(hash);
 }
+
+#include "apollonsearchtab.moc"
+
