@@ -2,8 +2,8 @@
                           apollonsearchitemview.cpp  -  description
                              -------------------
 begin		: Dec 05 2003
-copyright	: (C) 2002 by Bastiaan Naber, (C) 2002 by Robert Wittams
-email		: bastiaan@ricardis.tudelft.nl
+copyright	: (C) 2005 by Martin Koebele, (C) 2002 by Bastiaan Naber, (C) 2002 by Robert Wittams
+email		: martin@mkoebele.de
 description	: 
 
  ***************************************************************************/
@@ -33,7 +33,8 @@ description	:
 ApollonSearchViewItem::ApollonSearchViewItem(QListView *parent, bool child) :
   QListViewItem(parent),
   m_child(child),
-  m_availSlots(0)
+  m_availSlots(0),
+  isDownloadItem(false)
 {
 	m_loader = KGlobal::iconLoader();
 }
@@ -41,7 +42,8 @@ ApollonSearchViewItem::ApollonSearchViewItem(QListView *parent, bool child) :
 ApollonSearchViewItem::ApollonSearchViewItem(QListView *parent, QListViewItem *after, bool child) :
 QListViewItem(parent, after),
   m_child(child),
-  m_availSlots(0)
+  m_availSlots(0),
+  isDownloadItem(false)
 {
 	m_loader = KGlobal::iconLoader();
 }
@@ -49,7 +51,8 @@ QListViewItem(parent, after),
 
 ApollonSearchViewItem::ApollonSearchViewItem(QListViewItem *parent, bool child) :
   QListViewItem(parent),
-  m_child(child)
+  m_child(child),
+  isDownloadItem(false)
 {
 	m_availSlots = (static_cast<ApollonSearchViewItem*>(parent))->availSlots();
 	m_availSlots = 1;
@@ -215,14 +218,23 @@ void ApollonSearchViewItem::paintCell(QPainter *p, const QColorGroup &cg, int co
 	const QColor grey(180, 180, 180);
 	QColorGroup newCG(cg);
 	QColorGroup newCGHi(cg);
+	QColorGroup newCGDownload(cg);
 	newCG.setColor(QColorGroup::Text, grey);
 	newCGHi.setColor(QColorGroup::Text, QColor(0,0,255));
-	if ( m_availSlots == 0 )
-		QListViewItem::paintCell(p, newCG, column, width, align);
-	else if ( m_availSlots >= 4 )
-		QListViewItem::paintCell(p, newCGHi, column, width, align);
-	else
-		QListViewItem::paintCell(p, cg, column, width, align);
+	newCGDownload.setColor(QColorGroup::Text, QColor(0,255,0));
+
+
+	if (isDownloadItem) {
+		QListViewItem::paintCell(p, newCGDownload, column, width, align);
+	}
+	else {
+		if ( m_availSlots == 0 )
+        	        QListViewItem::paintCell(p, newCG, column, width, align);
+      		else if ( m_availSlots >= 4 )
+                	QListViewItem::paintCell(p, newCGHi, column, width, align);
+        	else
+                	QListViewItem::paintCell(p, cg, column, width, align);
+	}
 }
 
 
@@ -249,6 +261,16 @@ void ApollonSearchViewItem::setIcon()
 	{
 		setPixmap(0, m_loader->loadIcon("soulseek", KIcon::Small));
 	}
+	else if(m_protocol == "Ares")
+	{
+		setPixmap(0, m_loader->loadIcon("ares", KIcon::Small));
+	}
+        else
+        {
+                setPixmap(0, m_loader->loadIcon("unknown",KIcon::Small));
+        }
+
+	isDownloadItem = false;
 
 }
 
@@ -274,6 +296,17 @@ void ApollonSearchViewItem::setDownloadIcon()
 	{
 		setPixmap(0, m_loader->loadIcon("soulseekdown", KIcon::Small));
 	}
+	else if(m_protocol == "Ares")
+	{
+		setPixmap(0, m_loader->loadIcon("aresdown", KIcon::Small));
+	}
+	else 
+	{
+		setPixmap(0, m_loader->loadIcon("button_ok",KIcon::Small));
+	}	
+
+
+	isDownloadItem = true;
 	
 }
 
