@@ -2,8 +2,8 @@
                           apollonsearchitemview.h  -  description
                              -------------------
 begin		: Dec 05 2003
-copyright	: (C) 2002 by Bastiaan Naber, (C) 2002 by Robert Wittams
-email		: bastiaan@ricardis.tudelft.nl
+copyright       : (C) 2005 by Martin Koebele, (C) 2002 by Bastiaan Naber, (C) 2002 by Robert Wittams
+email           : martin@mkoebele.de
 description	: 
 
  ***************************************************************************/
@@ -112,6 +112,7 @@ class ApollonSearchViewItem : public QListViewItem
 	private:
 		bool m_child;
 		int m_availSlots;
+		bool isDownloadItem;
 		KIconLoader     *m_loader;
 };
 
