@@ -152,6 +152,10 @@ void ApollonTransferViewItem::updateIcon(const QString &protocolName, const QStr
 		{
 			m_icon = "soulseekdown";
 		}
+		else if(protocolName=="Ares")
+		{
+			m_icon = "aresdown";
+		}
 		else
 		{
 			m_icon = "1downarrow";
@@ -175,6 +179,10 @@ void ApollonTransferViewItem::updateIcon(const QString &protocolName, const QStr
 		{
 			m_icon = "soulseekup";
 		}
+		else if(protocolName=="Ares")
+		{
+			m_icon = "aresup";
+		}
 		else
 		{
 			m_icon = "1uparrow";
