@@ -51,7 +51,7 @@ bool FirstRunWizard::checkFirstRun()
 		
 		//where are the plugins installed?
 		QDir installedPath ("/usr/share/giFT/giftd.conf.template");
-		if (installedPath.exists()) {
+		if (QFile::exists(installedPath.path())) {
 			installedPath = "/usr/share/giFT/";
 		}
 		else {
